@@ -8,7 +8,9 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "/usr/obj/i386/gst-plugins-bad-0.10.20/gst-plugins-bad-0.10.20/gst-libs/gst/interfaces/photography.h" */
+/* enumerations from "/usr/obj/ports/gst-plugins-bad-0.10.22/gst-plugins-bad-0.10.22/gst-libs/gst/interfaces/photography.h" */
+GType gst_photography_noise_reduction_get_type (void);
+#define GST_TYPE_PHOTOGRAPHY_NOISE_REDUCTION (gst_photography_noise_reduction_get_type())
 GType gst_white_balance_mode_get_type (void);
 #define GST_TYPE_WHITE_BALANCE_MODE (gst_white_balance_mode_get_type())
 GType gst_colour_tone_mode_get_type (void);
