@@ -73,21 +73,14 @@ struct _GstBaseVideoDecoder
   GstAdapter *input_adapter;
   GstAdapter *output_adapter;
 
-  GList *frames;
-
   gboolean have_sync;
   gboolean discont;
   gboolean started;
 
-  GstVideoState state;
-  GstSegment segment;
-
   gboolean sink_clipping;
 
   guint64 presentation_frame_number;
-  guint64 system_frame_number;
 
-  GstCaps *caps;
   gboolean have_src_caps;
 
   GstVideoFrame *current_frame;
@@ -99,9 +92,6 @@ struct _GstBaseVideoDecoder
 
   GstClockTime timestamp_offset;
 
-  gdouble proportion;
-  GstClockTime earliest_time;
-
   //GstBuffer *codec_data;
 
   guint64 input_offset;
@@ -117,6 +107,9 @@ struct _GstBaseVideoDecoder
 
   GList *timestamps;
   gboolean have_segment;
+
+  /* FIXME before moving to base */
+  void *padding[GST_PADDING_LARGE];
 };
 
 struct _GstBaseVideoDecoderClass
@@ -133,15 +126,22 @@ struct _GstBaseVideoDecoderClass
       int offset, int n);
   GstFlowReturn (*parse_data) (GstBaseVideoDecoder *decoder, gboolean at_eos);
   GstFlowReturn (*finish) (GstBaseVideoDecoder *coder);
-  GstFlowReturn (*handle_frame) (GstBaseVideoDecoder *coder, GstVideoFrame *frame,
-				 GstClockTimeDiff deadline);
+  GstFlowReturn (*handle_frame) (GstBaseVideoDecoder *coder, GstVideoFrame *frame);
   GstFlowReturn (*shape_output) (GstBaseVideoDecoder *coder, GstVideoFrame *frame);
   GstCaps *(*get_caps) (GstBaseVideoDecoder *coder);
 
+  guint32 capture_mask;
+  guint32 capture_pattern;
+
+  /* FIXME before moving to base */
+  void *padding[GST_PADDING_LARGE];
 };
 
 GType gst_base_video_decoder_get_type (void);
 
+void gst_base_video_decoder_class_set_capture_pattern (GstBaseVideoDecoderClass *klass,
+    guint32 mask, guint32 pattern);
+
 int gst_base_video_decoder_get_width (GstBaseVideoDecoder *coder);
 int gst_base_video_decoder_get_height (GstBaseVideoDecoder *coder);
 
@@ -168,9 +168,14 @@ void gst_base_video_decoder_set_sync_point (GstBaseVideoDecoder *base_video_deco
 
 void gst_base_video_decoder_set_src_caps (GstBaseVideoDecoder *base_video_decoder);
 
+GstBuffer * gst_base_video_decoder_alloc_src_buffer (GstBaseVideoDecoder *
+    base_video_decoder);
 GstFlowReturn gst_base_video_decoder_alloc_src_frame (GstBaseVideoDecoder *base_video_decoder,
     GstVideoFrame *frame);
 
+GstClockTimeDiff gst_base_video_decoder_get_max_decode_time (
+    GstBaseVideoDecoder *base_video_decoder, GstVideoFrame *frame);
+
 G_END_DECLS
 
 #endif
